#include <stdio.h>
#include <string>
#include "../graphics/BustaGraphics.h"
#include "../networking/BustaNetClient.h"
#include "../Models/BustaModelGameState.h"

using namespace std;

#define LEFT SDLK_LEFT
#define QUIT SDLK_ESCAPE

int main(int argc, char** argv){
	// init SDL
	if (SDL_Init(0) == -1)
	{
		printf("SDL_Init: %s\n", SDL_GetError());
		return (1);
	}

	BustaNetClient* network = new BustaNetClient();

	SDL_Surface* screen;
	screen = SDL_SetVideoMode(640,480,32,SDL_SWSURFACE|SDL_RESIZABLE|SDL_HWPALETTE);

	BustaGraphics* graphics = new BustaGraphics(screen);
	BustaModelGameState* gs = new BustaModelGameState();

	graphics->drawSPGame(gs);

	char* error = network->init();

	if(error !=NULL)
		printf("Error initializing the networking client");

	connect_resp* conresp;

	//string ipadd = "192.168.0.4";
	//string ipadd = "128.208.61.125";
	//string ipadd = "127.0.0.1";
	if (argc > 1)
	{
		printf("Connecting to: %s\n\n", argv[1]);
		conresp = network->connect(argv[1], 65535);
	}
	else{
		printf("Improper server, not connecting to network");
	}

	bool done = false;

	while(!done)
	{
		SDL_Event event;

		while ( SDL_PollEvent(&event) && !done)
		{
			switch(event.type){
				case SDL_MOUSEMOTION:
					printf("We got a motion event.\n");
					printf("Current mouse position is: (%d, %d)\n", event.motion.x, event.motion.y);
					break;
				case SDL_KEYDOWN:
					printf("We got a keyboard event.\n");
					if(event.key.keysym.sym==LEFT){
						printf("Going left\n");
					}
					if(event.key.keysym.sym==QUIT){
						printf("Exiting loop");
						done = true;
					}
					break;
				default:
					printf("Unhandled Event!\n");
					break;
			}
		}
	}  

	if(argc>1){
		delete(conresp);
	}
	delete(network);
	delete(graphics);
	delete(gs);

	return 0;




}