/* 
 * BustaGraphics.h
 * Busta' Sandwich Graphics Engine
 * Authors: Julian Chan, Thomas Patecky
 *
 * Created: July 13, 2005
 * Last Modified July 15, 2005
 */

#ifndef __BUSTAGRAPHICS_H__
#define __BUSTAGRAPHICS_H__

#define DEFAULT_SCR_WIDTH		640
#define DEFAULT_SCR_HEIGHT		480
#define	DEFAULT_FULLSCR_ON		false	


#include "SDL.h"

#include "BustaGraphicsSprites.h"



/**
 * @class BustaGraphics
 * @brief contains methods for displaying graphics
 *
 */
class BustaGraphics
{
	private:
		SDL_Surface* myScreen;
		BustaGraphicsSprites* mySprites;

		//Private drawing functions

		/**
		 * @brief Draws board
		 *
		 *
		 * @param gs A pointer to the BustaModelGameState.
		 */
		void drawBoard(BustaModelGameState* gs);

		/**
		 * @brief Draws a food tile
		 *
		 *
		 * @param food_piece A pointer to the BustaModelFoodPiece.
		 * @param row Row to place tile in.
		 * @param col Column to place tile in.
		 */
		void drawFoodPiece(BustaModelFoodPiece* food_piece, int row, int col);
		void updateRect(SDL_Rect* rect, SDL_Surface* rectSurface);
	
	public:
		BustaGraphics(SDL_Surface* screen);
		/**
		* @brief Draws a window containg a singleplayer game
		* @param gs A pointer to the Game State.
		*/
		void drawSPGame(BustaModelGameState* gs);
		//Single-Player Game

		/**
		* @brief Draws the chef
		* @param c A pointer to the Chef Model.
		*/
		void drawChef(BustaModelChef c);

		/**
		* @brief Draws the tip jar
		* @param tj A pointer to the Tip Jar Model.
		*/
		void drawTipJar(BustaModelTipJar tj);

		/**
		* @brief Draws the score
		* @param score The Score.
		*/
		void drawScore(int score);

		//Multi-Player Game

		/**
		* @brief Draws a window containg a multiplayer game
		* @param gs A pointer to the Game State.
		*/
		void drawMPGame(BustaModelGameState gs);
		/**
		* @brief Draws the opponent's game board
		* @param gs A pointer to the Game State.
		*/
		void drawOpponentBoard(BustaModelGameState gs);

		//Other screens

		/**
		* @brief Draws the main screen
		*/
		void drawMainScreen();

		/**
		* @brief Draws the chef selection screen
		*/
		void drawChefSelelection();

		/**
		* @brief Draws the high scores screen
		*/
		void drawHighScores();

		/**
		* @brief Draws the rankings screen
		*/
		void drawRankings();

		/**
		* @brief Draws the options screen
		*/
		void drawOptions();

		/**
		* @brief Draws the connect screen
		*/
		void drawConnection();

};


#endif
