/*	Filename:		BustaModelGameState.h
 *	Description:	Busta' Sandwich GameState model.
 *
 */

#define NULL 0

#ifndef BUSTA_SANDWICH_GAMESTATE
#define BUSTA_SANDWICH_GAMESTATE

#include "BustaModelFoodPiece.h"
#include "BustaModelCustomer.h"
#include "BustaModelTipJar.h"
#include "BustaModelChef.h"
#include "BustaModelCursor.h"

/**
 * @class BustaModelGameState
 *
 */
class BustaModelGameState
{
	public:
		/**
		 * @brief Constructor
		 *
		 * Initializes variables
		 */
		BustaModelGameState();

		/**
		 * @brief Destructor
		 *
		 */
		~BustaModelGameState();


		/**
		 * @brief Gets the score of the player
		 */
		int getScore();

		/**
		 * @brief Sets the score of the player
		 */
		void setScore(int s);

		/**
		 * @brief Adds a Customer to the queue, if more than two Customers deletes the oldest one
		 */
		void addCustomer(BustaModelCustomer* c);
		
		/**
		 * @brief Deletes the specified customer
		 */
		int removeCustomer(BustaModelCustomer* c);

		/**
		 * @brief Returns a pointer to the customer in the nth location in the queue
		 */
		BustaModelCustomer*  getCustomer(int n);

		/**
		 * @brief Returns a pointer to the tip jar
		 */
		BustaModelTipJar* getTipJar();

		/**
		 * @brief Returns a pointer to the FoodPiece in the specified row and column
		 */
		BustaModelFoodPiece* getBoard(int i,int j);

		/**
		 * @brief Sets board location to specified foodPiece
		 */
		void setBoard(int i,int j, BustaModelFoodPiece* fp);

		/**
		 * @brief Deletes the foodpiece in the specified location
		 */
		void removeFromBoard(int i, int j);

	private:
		int score;
		BustaModelFoodPiece* board[5][5];
		BustaModelCustomer* customers[3];
		BustaModelTipJar* tips;
		BustaModelChef* chef;
		BustaModelCursor* cursor;
};

#endif