/**
 * @struct connect_resp BustaNetInternal.h
 *
 * @brief Outlines the outcome of a client connection attempt
 *
 * Structure containing information regarding the outcome of a client trying to connect
 *	to a BustaSandwich multiplayer server.
 */
struct connect_resp
{
	/**
	 * @var bool accept
	 * @brief Notes the success or failure of the connection attempt
	 *
	 * This variable has a value of true when the connection attempt is successful and false
	 *	on connection failure.
	 */
	bool accept;

	/**
	 * @var char* message
	 * @brief Contains the details of the connection success or failure.
	 *
	 * This string contains a message denoting the details of the connection attempt.  On a connection
	 *	success, the message simply states that the connection was successful.  On connection failures,
	 *	the message contains information regarding the reason for failure.
	 */
	char* message;

	/**
	 * @var int playerID
	 * @brief Player Identification number on successful connection
	 *
	 * On a successful connection, this is the player's identification number.  This number if used to
	 *	reference the player by the server.  On a failed connection attemp, this integer holds the value -1.
	 */
	int playerID;
};
